#!/usr/local/perl -w -I.
# Machine translation by Syntactic Transfer
# Uses PC-PATR for parsing, then applies transfer rules
#
# Author: George Wilson - gwilson@computer.org
# Copyright 2010 George Wilson

use SynTransfer;
use Getopt::Std;

our(%Opt);
getopts('c:kdq', \%Opt);

@OffOn = ("Off", "On");

## Handle command line options
unless($Opt{'c'}) { $Opt{'c'} = "ST_Config.txt"; }
if(-e $Opt{'c'}) { require($Opt{'c'}); }
else { print STDERR "Cannot find configuration file: $Opt{'c'}\n"; exit; }
unless($Opt{'k'}) { $Opt{'k'} = 0; }
if($Opt{'d'}) { $SynTransfer::ST_DEBUG = 1; }
if($Opt{'q'}) { $SynTransfer::ST_QUIET = 1; }

if(($^O =~ /WIN/i) && ($^O !~ /DARWIN/i)) {
    require Win32::Console;
    Win32::Console::OutputCP($ST_CodePage);
    system("TITLE Syntactic Transfer"); }

unless($PCPATR_EXE && (-e $PCPATR_EXE)) {
    print STDERR "Cannot find PC-PATR.\n";
    sleep(4);
    exit; }

&InitializeAll;
my($LeftOver);
unless($SynTransfer::ST_QUIET) { 
    print STDERR &StatusMessage; 
    &HelpMessage;
    print "Sentence: "; }

while($Sentence = <>) {
    chomp($Sentence);
    unless($Sentence =~ /\S/) {
	print "Sentence: ";  next; }
    if($Sentence =~ /\A(Q(UIT)?|Exit)\Z/i) { last; }
    if($Sentence =~ /\AD(ebug)?\s*\Z/i)    { 
	$SynTransfer::ST_DEBUG = ($SynTransfer::ST_DEBUG + 1) % 2;
	print "Debug Information " , $OffOn[$SynTransfer::ST_DEBUG], "\n";
	print "Sentence: "; next; }
    if($Sentence =~ /\AF(eatures)?\s*\Z/i)    { 
	$SynTransfer::ST_DisplayFeatures = ($SynTransfer::ST_DisplayFeatures + 1) % 2;
	print "Feature Display " , $OffOn[$SynTransfer::ST_DisplayFeatures], "\n";
	print "Sentence: "; next; }
    if($Sentence =~ /\AK(eep)?\s*\Z/i)    { 
	$Opt{'k'} = ($Opt{'k'} + 1) % 2;
	print "Keep Temp Dictionary " , $OffOn[$Opt{'k'}], "\n";
	print "Sentence: "; next; }
    if($Sentence =~ /\AS(tatus)?\s*\Z/i)    { 
	print STDERR &StatusMessage;
	print "Sentence: "; next; }
    if($Sentence =~ /\AH(elp)?\s*\Z/msi) { 
	&HelpMessage; 
	print "\nSentence: "; next; }

    ## Use PC-PATR to parse sentence
    $XLated = ST_Translate($Sentence);
    if($XLated) { print "$XLated\n"; }
    else { 
	unless($SynTransfer::ST_QUIET) {
	    print "ST: No Parse Found.\n"; } }
    unless($SynTransfer::ST_QUIET) {  print "\nSentence: "; }
}
unless($Opt{'k'}) { &FinalCleanup; }


#########################
## End of main routine ##
##  Begin subroutines  ##
#########################

sub HelpMessage {
    print STDERR "Commands:\n";
    print STDERR "H(elp)        - show this message\n";    
    print STDERR "D(ebug)       - toggle display of debug information\n";
    print STDERR "K(eep)        - toggle Keep temp dictionary\n";
    print STDERR "S(tatus)      - show status message\n";
    print STDERR "Q(uit)        - exit program\n\n";
    return;
}

# Copyright 2010 George Wilson

